==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-cpuload/cpuload_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <location filename="../../lxqtcpuload.cpp" line="125"/>
        <source>CPU load %1%</source>
        <translation>CPU load %1%</translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <location filename="../../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation>Paramétrage de &apos;Charge du processeur&apos;</translation>
    </message>
    <message>
        <location filename="../../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Généraux</translation>
    </message>
    <message>
        <location filename="../../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Afficher le texte</translation>
    </message>
    <message>
        <location filename="../../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>Intervalle des màj :</translation>
    </message>
    <message>
        <location filename="../../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>sec</translation>
    </message>
    <message>
        <location filename="../../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>Orientation de la barre :</translation>
    </message>
    <message>
        <location filename="../../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation>Largeur de la barre :</translation>
    </message>
    <message>
        <location filename="../../lxqtcpuloadconfiguration.cpp" line="68"/>
        <source>Bottom up</source>
        <translation>du bas vers le haut</translation>
    </message>
    <message>
        <location filename="../../lxqtcpuloadconfiguration.cpp" line="69"/>
        <source>Top down</source>
        <translation>du haut vers le bas</translation>
    </message>
    <message>
        <location filename="../../lxqtcpuloadconfiguration.cpp" line="70"/>
        <source>Left to right</source>
        <translation>de la gauche vers la droite</translation>
    </message>
    <message>
        <location filename="../../lxqtcpuloadconfiguration.cpp" line="71"/>
        <source>Right to left</source>
        <translation>de la droite vers la gauche</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-cpuload/cpuload_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <location filename="../../../lxqtcpuload.cpp" line="125"/>
        <source>CPU load %1%</source>
        <translation>CPU load %1%</translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation>Paramétrage de &apos;Charge du processeur&apos;</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Généraux</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Afficher le texte</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>Intervalle des màj :</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>sec</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>Orientation de la barre :</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation>Largeur de la barre :</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="68"/>
        <source>Bottom up</source>
        <translation>du bas vers le haut</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="69"/>
        <source>Top down</source>
        <translation>du haut vers le bas</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="70"/>
        <source>Left to right</source>
        <translation>de la gauche vers la droite</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="71"/>
        <source>Right to left</source>
        <translation>de la droite vers la gauche</translation>
    </message>
</context>
</TS>
